<?php


namespace Cache\Controller;

use Zend\Console\ColorInterface as Color;
use Zend\Mvc\Controller\AbstractActionController;
use Zend\ModuleManager\Listener\ListenerOptions;

class FwCacheController extends AbstractActionController
{
    public function clearConfigAction()
    {
        $console = $this->getConsole();
        $options = $this->getOptions();

        if (!$options->getConfigCacheEnabled()) {
            $console->writeLine('Config cache is not enabled, will not clear config cache', Color::RED);
            return;
        }

        $file = $options->getConfigCacheFile();
        if (!is_file($file) || !is_writable($file)) {
            $console->writeLine(sprintf('File %s cannot be found or is not writable', $file), Color::WHITE, Color::RED);
            return;
        }

        unlink($file);
        $console->writeLine(sprintf(
            'Configuration file %s cleared', $file
        ));
    }

    public function clearModuleMapAction()
    {
        $console = $this->getConsole();
        $options = $this->getOptions();

        if (!$options->getModuleMapCacheEnabled()) {
            $console->writeLine('Module map is not enabled, will not clear module map', Color::RED);
            return;
        }

        $file = $options->getModuleMapCacheFile();
        if (!is_file($file) || !is_writable($file)) {
            $console->writeLine(sprintf('File %s cannot be found or is not writable', $file), Color::WHITE, Color::RED);
            return;
        }

        unlink($file);
        $console->writeLine(sprintf(
            'Module map file %s cleared', $file
        ));
    }

    protected function getConsole()
    {
        return $this->getServiceLocator()->get('console');
    }

    protected function getOptions()
    {
        $serviceLocator  = $this->getServiceLocator();
        $configuration   = $serviceLocator->get('ApplicationConfig');
        $listenerOptions = new ListenerOptions($configuration['module_listener_options']);

        return $listenerOptions;
    }
}
